@@ -61,7 +61,8 @@ tar_rep_map <- function(
   resources = targets::tar_option_get("resources"),
   storage = targets::tar_option_get("storage"),
   retrieval = targets::tar_option_get("retrieval"),
-  cue = targets::tar_option_get("cue")
+  cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description")
 ) {
   targets::tar_warn_deprecate(
     "tar_rep_map() in tarchetypes is deprecated ",
