@@ -8,9 +8,13 @@ targets::tar_test("tar_cue_skip(FALSE)", {
     targets::tar_target(x, 1L, cue = tar_cue_skip(0 > 0))
   )
   targets::tar_make(callr_function = NULL)
-  expect_equal(targets::tar_progress()$name, "x")
+  progress <- targets::tar_progress()
+  progress <- progress[progress$progress != "skipped", ]
+  expect_equal(progress$name, "x")
   targets::tar_make(callr_function = NULL)
-  expect_equal(nrow(targets::tar_progress()), 0L)
+  progress <- targets::tar_progress()
+  progress <- progress[progress$progress != "skipped", ]
+  expect_equal(nrow(progress), 0L)
 })
 
 targets::tar_test("tar_cue_skip(TRUE)", {
@@ -24,6 +28,8 @@ targets::tar_test("tar_cue_skip(TRUE)", {
   )
   for (index in seq_len(2L)) {
     targets::tar_make(callr_function = NULL)
-    expect_equal(nrow(targets::tar_progress()), 0L)
+    progress <- targets::tar_progress()
+    progress <- progress[progress$progress != "skipped", ]
+    expect_equal(nrow(progress), 0L)
   }
 })
